#
# spec file for package ghc-scotty
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name scotty
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.11.2
Release:        1.1
Summary:        Haskell web framework inspired by Ruby's Sinatra, using WAI and Warp
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-blaze-builder-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-data-default-class-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-fail-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-monad-control-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-nats-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-regex-compat-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-base-devel
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-wai-devel
BuildRequires:  ghc-wai-extra-devel
BuildRequires:  ghc-warp-devel
%if %{with tests}
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-hpc-coveralls-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-wai-devel
BuildRequires:  ghc-lifted-base-devel
%endif

%description
A Haskell web framework inspired by Ruby's Sinatra, using WAI and Warp.

' &#123;-&#35; LANGUAGE OverloadedStrings &#35;-&#125;

import Web.Scotty

import Data.Monoid (mconcat)

main = scotty 3000 $ &#32;&#32;get &#34;/:word&#34; $ do
&#32;&#32;&#32;&#32;beam <- param &#34;word&#34; &#32;&#32;&#32;&#32;html $
mconcat [&#34;&#60;h1&#62;Scotty, &#34;, beam, &#34; me up!&#60;/h1&#62;&#34;]
'

Scotty is the cheap and cheerful way to write RESTful, declarative web
applications.

* A page is as simple as defining the verb, url pattern, and Text content.

* It is template-language agnostic. Anything that returns a Text value will do.

* Conforms to WAI Application interface.

* Uses very fast Warp webserver by default.

As for the name: Sinatra + Warp = Scotty.

[WAI] <http://hackage.haskell.org/package/wai>

[Warp] <http://hackage.haskell.org/package/warp>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc README.md changelog.md examples

%changelog
* Mon Jul  9 2018 psimons@suse.com
- Update scotty to version 0.11.2.
  [#]# 0.11.2 [2018.07.02]
  * Migrate from `Network` to `Network.Socket` to avoid deprecation warnings.
* Thu Apr 12 2018 psimons@suse.com
- Update scotty to version 0.11.1.
  A more detailed change log is not available.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Wed Apr 19 2017 psimons@suse.com
- Update to version 0.11.0 revision 5 with cabal2obs.
* Wed Jan  4 2017 psimons@suse.com
- Update to version 0.11.0 revision 4 with cabal2obs.
* Wed Aug 17 2016 psimons@suse.com
- Update to version 0.11.0 revision 3 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.11.0 revision 2 with cabal2obs.
- Remove obsolete remove-nats.patch , we ship ghc-nats now.
* Fri Mar 25 2016 mimi.vx@gmail.com
- relax uppper bound of aeson
* Fri Jan 29 2016 mimi.vx@gmail.com
- update to 0.11.0
- refreshed remove-nats.patch
  * IO exceptions are no longer automatically turned into ScottyErrors by liftIO.
    Use liftAndCatchIO to get that behavior.
  * New finish function.
  * Text values are now leniently decoded from ByteStrings.
  * Added MonadFail instance for ScottyT
  * Lots of bound bumps on dependencies.
* Tue Jan 26 2016 mimi.vx@gmail.com
- relax upper bounds for some packages
* Thu Oct 22 2015 mimi.vx@gmail.com
- initial commit
- remove-nats.patch for remove unneeded dep
